@@ -8,11 +8,11 @@
 #include "KSWidget.h"
 #include "spectacle_gui_debug.h"
 
-#include "KSImageWidget.h"
-#include "settings.h"
-#include "SmartSpinBox.h"
-#include "ProgressButton.h"
 #include "ExportManager.h"
+#include "KSImageWidget.h"
+#include "ProgressButton.h"
+#include "SmartSpinBox.h"
+#include "settings.h"
 
 #include <QAction>
 #include <QApplication>
@@ -44,6 +44,7 @@ KSWidget::KSWidget(Platform::GrabModes theGrabModes, QWidget *parent)
 #ifdef KIMAGEANNOTATOR_FOUND
     mAnnotator = new kImageAnnotator::KImageAnnotator();
     mAnnotator->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    mAnnotator->setCanvasColor(QColor(255, 255, 255, 0));
     mStack->addWidget(mAnnotator);
 #endif
 
@@ -52,14 +53,11 @@ KSWidget::KSWidget(Platform::GrabModes theGrabModes, QWidget *parent)
     mCaptureArea = new QComboBox(this);
 
     if (theGrabModes.testFlag(Platform::GrabMode::AllScreens)) {
-
-        QString lFullScreenLabel = QApplication::screens().count() == 1
-                ? i18n("Full Screen")
-                : i18n("Full Screen (All Monitors)");
+        QString lFullScreenLabel = QApplication::screens().count() == 1 ? i18n("Full Screen") : i18n("Full Screen (All Monitors)");
 
         mCaptureArea->insertItem(0, lFullScreenLabel, Spectacle::CaptureMode::AllScreens);
     }
-    if (theGrabModes.testFlag(Platform::GrabMode::AllScreensScaled) &&  QApplication::screens().count() > 1) {
+    if (theGrabModes.testFlag(Platform::GrabMode::AllScreensScaled) && QApplication::screens().count() > 1) {
         QString lFullScreenLabel = i18n("Full Screen (All Monitors, scaled)");
         mCaptureArea->insertItem(1, lFullScreenLabel, Spectacle::CaptureMode::AllScreensScaled);
     }
@@ -120,8 +118,9 @@ KSWidget::KSWidget(Platform::GrabModes theGrabModes, QWidget *parent)
     mWindowDecorations->setObjectName(QStringLiteral("kcfg_includeDecorations"));
 
     mCaptureTransientOnly = new QCheckBox(i18n("Capture the current pop-up only"), this);
-    mCaptureTransientOnly->setToolTip(i18n("Capture only the current pop-up window (like a menu, tooltip etc).\n"
-                                           "If disabled, the pop-up is captured along with the parent window"));
+    mCaptureTransientOnly->setToolTip(
+        i18n("Capture only the current pop-up window (like a menu, tooltip etc).\n"
+             "If disabled, the pop-up is captured along with the parent window"));
     mCaptureTransientOnly->setEnabled(false);
     mCaptureTransientOnly->setObjectName(QStringLiteral("kcfg_transientOnly"));
 
@@ -143,7 +142,7 @@ KSWidget::KSWidget(Platform::GrabModes theGrabModes, QWidget *parent)
     mCancelAction = new QAction(QIcon::fromTheme(QStringLiteral("dialog-cancel")), i18n("Cancel"), this);
     mCancelAction->setShortcut(QKeySequence::Cancel);
     connect(mCancelAction, &QAction::triggered, this, [this] {
-        emit screenshotCanceled();
+        Q_EMIT screenshotCanceled();
         setButtonState(State::TakeNewScreenshot);
     });
 
@@ -166,8 +165,23 @@ KSWidget::KSWidget(Platform::GrabModes theGrabModes, QWidget *parent)
     mRightLayout->addWidget(mTakeScreenshotButton, 1, Qt::AlignHCenter);
     mRightLayout->setContentsMargins(10, 0, 0, 10);
 
+    mPlaceholderLabel = new QLabel;
+
+    QFont placeholderLabelFont;
+    // To match the size of a level 2 Heading/KTitleWidget
+    placeholderLabelFont.setPointSize(qRound(placeholderLabelFont.pointSize() * 1.3));
+    mPlaceholderLabel->setFont(placeholderLabelFont);
+    mPlaceholderLabel->setTextInteractionFlags(Qt::NoTextInteraction);
+    mPlaceholderLabel->setWordWrap(true);
+    mPlaceholderLabel->setAlignment(Qt::AlignCenter);
+    // Match opacity of QML placeholder label component
+    auto *effect = new QGraphicsOpacityEffect(mPlaceholderLabel);
+    effect->setOpacity(0.5);
+    mPlaceholderLabel->setGraphicsEffect(effect);
+
     mMainLayout = new QGridLayout();
 
+    mMainLayout->addWidget(mPlaceholderLabel, 0, 0, 1, 1);
     mMainLayout->addWidget(mImageWidget, 0, 0, 1, 1);
     mMainLayout->addLayout(mRightLayout, 0, 1, 1, 1);
     mMainLayout->setColumnMinimumWidth(0, 320);
@@ -190,9 +204,9 @@ KSWidget::KSWidget(Platform::GrabModes theGrabModes, QWidget *parent)
 
 int KSWidget::imagePaddingWidth() const
 {
-    int lRightLayoutLeft  = 0;
+    int lRightLayoutLeft = 0;
     int lRightLayoutRight = 0;
-    int lMainLayoutRight  = 0;
+    int lMainLayoutRight = 0;
 
     mRightLayout->getContentsMargins(&lRightLayoutLeft, nullptr, &lRightLayoutRight, nullptr);
     mMainLayout->getContentsMargins(nullptr, nullptr, &lMainLayoutRight, nullptr);
@@ -204,10 +218,24 @@ int KSWidget::imagePaddingWidth() const
     return lPaddingWidth;
 }
 
+bool KSWidget::isScreenshotSet()
+{
+    return mImageWidget->isPixmapSet();
+}
+
 // public slots
 
+void KSWidget::showPlaceholderText(const QString &label)
+{
+    mPlaceholderLabel->setText(label);
+    mPlaceholderLabel->show();
+}
+
 void KSWidget::setScreenshotPixmap(const QPixmap &thePixmap)
 {
+    if (mPlaceholderLabel->isVisible()) {
+        mPlaceholderLabel->hide();
+    }
     mImageWidget->setScreenshot(thePixmap);
 }
 
@@ -231,13 +259,11 @@ void KSWidget::newScreenshotClicked()
 {
     int lDelay = mCaptureOnClick->isChecked() ? -1 : (mDelayMsec->value() * 1000);
     auto lMode = static_cast<Spectacle::CaptureMode>(mCaptureArea->currentData().toInt());
-    if (mTransientWithParentAvailable &&
-        lMode == Spectacle::CaptureMode::WindowUnderCursor &&
-        !(mCaptureTransientOnly->isChecked())) {
+    if (mTransientWithParentAvailable && lMode == Spectacle::CaptureMode::WindowUnderCursor && !(mCaptureTransientOnly->isChecked())) {
         lMode = Spectacle::CaptureMode::TransientWithParent;
     }
     setButtonState(State::Cancel);
-    emit newScreenshotRequest(lMode, lDelay, mMousePointer->isChecked(), mWindowDecorations->isChecked());
+    Q_EMIT newScreenshotRequest(lMode, lDelay, mMousePointer->isChecked(), mWindowDecorations->isChecked());
 }
 
 void KSWidget::onClickStateChanged(int theState)
@@ -252,7 +278,7 @@ void KSWidget::onClickStateChanged(int theState)
 void KSWidget::captureModeChanged(int theIndex)
 {
     Spectacle::CaptureMode captureMode = static_cast<Spectacle::CaptureMode>(mCaptureArea->itemData(theIndex).toInt());
-    switch(captureMode) {
+    switch (captureMode) {
     case Spectacle::CaptureMode::WindowUnderCursor:
         mWindowDecorations->setEnabled(true);
         if (mTransientWithParentAvailable) {
